@@ -18,11 +18,6 @@
     You should have received a copy of the GNU General Public License
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-================================================================================
-
-	The Track Class can be used to store and work on Bars. It's also 
-	designed to be used with Instruments in mind.
-
 ================================================================================
 
 """
@@ -30,6 +25,10 @@
 from mt_exceptions import InstrumentRangeError
 
 class Track:
+	"""The Track class can be used to store [refMingusContainersBar Bars] \
+and to work on them. The class is also designed to be used with \
+[refMingusContainersInstrument Instruments], but this is optional. \
+Tracks can be stored together in [refMingusContainersComposition Compositions]"""
 
 	bars = []
 	instrument = None
@@ -39,18 +38,22 @@ class Track:
 		self.instrument = instrument
 
 	def add_bar(self, bar):
-		"""Adds a bar to the current track"""
+		"""Adds a [refMingusContainersBar Bar] to the current track"""
 		self.bars.append(bar)
 
 
 	def add_notes(self, note, duration = None):
-		"""Adds a Note, note as string or NoteContainer to the 
-		last Bar. If the Bar is full, a new one will automatically
-		be created. If the Bar is not full but the note can't fit in,
-		this method will return False. True otherwise. 
-		An InstrumentRangeError exception is being raised if an 
-		instrument is attached to the Track, but the note is not 
-		within the range of the instrument."""
+		"""Adds a [refMingusContainersNote Note], note as string or \
+[refMingusContainersNotecontainer NoteContainer] to the last \
+[refMingusContainersBar Bar]. If the [refMingusContainersBar Bar] is full, \
+a new one will automatically be created. If the [refMingusContainersBar Bar] \
+is not full but the note can't fit in, this method will return `False`. \
+True otherwise. 
+
+An !InstrumentRangeError exception will be raised if an \
+[refMingusContainersInstrument Instrument] is attached to the Track, \
+but the note turns out not to be within the range of the \
+[refMingusContainersInstrument Instrument]."""
 
 		if self.instrument != None:
 			if not(self.instrument.can_play_notes(note)):
@@ -71,8 +74,10 @@ class Track:
 		
 
 	def __add__(self, value):
-		"""Overloads the + operator for Tracks. Accepts Notes, 
-		notes as string, NoteContainers and Bars."""
+		"""Overloads the + operator for Tracks. Accepts \
+[refMingusContainersNote Notes], notes as string, \
+[refMingusContainersNotecontainer NoteContainers] and \
+[refMingusContainersBar Bars]."""
 
 		if hasattr(value, "bar"):
 			return self.add_bar(value)
@@ -82,8 +87,8 @@ class Track:
 			return self.add_notes(value)
 
 	def test_integrity(self):
-		"""Test whether all but the last bars contained
-		in this track are full."""
+		"""Test whether all but the last [refMingusContainersBar Bars] \
+contained in this track are full."""
 		for b in self.bars[:-1]:
 			if not ( b.is_full() ):
 				return False
@@ -94,9 +99,9 @@ class Track:
 		return self.bars[index]
 
 	def __setitem__(self, index, value):
-		"""Overloads the [] = notation for Tracks. Throws an
-		UnexpectedObjectError if the value being set is not a
-		mingus.containers.Bar object."""
+		"""Overloads the [] = notation for Tracks. Throws an \
+!UnexpectedObjectError if the value being set is not a \
+[refMingusContainersBar mingus.containers.Bar] object."""
 
 		if not ( hasattr (value, "bar") ):
 			raise UnexpectedObjectError,\
